@@ -1,21 +1,6 @@
-//
-//  Copyright (C) 1998 Matthias Hoelzer <hoelzer@kde.org>
-//  Copyright (C) 2002-2005 David Faure <faure@kde.org>
-//
-//  This program is free software; you can redistribute it and/or modify
-//  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
-//  (at your option) any later version.
-//
-//  This program is distributed in the hope that it will be useful,
-//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
-//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//  GNU General Public License for more details.
-//
-//  You should have received a copy of the GNU General Public License
-//  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-//
+//  SPDX-FileCopyrightText: 1998 Matthias Hoelzer <hoelzer@kde.org>
+//  SPDX-FileCopyrightText: 2002-2005 David Faure <faure@kde.org>
+//  SPDX-License-Identifier: GPL-2.0-or-later
 
 // Own
 #include <config-kdialog.h>
@@ -395,7 +380,7 @@ bool Widgets::slider(QWidget *parent, const QString &title, const QString &text,
     return retcode;
 }
 
-bool Widgets::calendar(QWidget *parent, const QString &title, const QString &text, QDate &result, const QDate& defaultEntry)
+bool Widgets::calendar(QWidget *parent, const QString &title, const QString &text, QDate &result, QDate defaultEntry)
 {
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
